Compass::Frameworks.register('slickmap',
                             :stylesheets_directory => File.join(File.dirname(__FILE__), 'compass-slickmap', 'stylesheets'),
                             :templates_directory   => File.join(File.dirname(__FILE__), 'compass-slickmap', 'templates'))